Raspi-Sump Simulations
======================

The following two scripts simply replace Raspberry Pi GPIO code with simulated readings to test how Raspi-Sump works.
You can even run this on Windows if you have Python installed.

To test out Raspi-Sump do the following

- copy the two simulation files to any folder
- create a directory for csv reports
- change the filename variable to whatever location you want on your system.
- run sim-pump-fail.py or sim-pump-working.py
- for sim-pump-fail.py you can enter your email information to test your email or sms email alerts.
